@@ -3,7 +3,7 @@ package Algorithm::Easing;
 use strict;
 use warnings;
 
-our $VERSION = '0.82';
+our $VERSION = '0.851';
 
 1;
 
@@ -27,7 +27,7 @@ Algorithm::Easing - Calculate eased translations between two positive whole inte
 
         # this example produces traditional 'bounce' output;
 
-        my $translation_mediator = Algorithm::Easing::Mediator->new(Algorithm::Easing::Mediator::Bounce->new);
+        my $translation_mediator = Algorithm::Easing::Mediator->new(Algorithm::Easing::Bounce->new);
 
         # total time for eased translation as a real positive integer value
         my $d = 2.5;
